fn check_block<'gcx>(
ctx: &LintContext<'_, '_>,
gcx: Gcx<'gcx>,
block: Block<'gcx>,
tainted: &mut HashSet<VariableId>,
) -> boolExpand description
Checks block, returning false once control cannot continue past a statement.
fn check_block<'gcx>(
ctx: &LintContext<'_, '_>,
gcx: Gcx<'gcx>,
block: Block<'gcx>,
tainted: &mut HashSet<VariableId>,
) -> boolChecks block, returning false once control cannot continue past a statement.