check_branches

Function check_branches 

fn check_branches<'gcx>(
    ctx: &LintContext<'_, '_>,
    gcx: Gcx<'gcx>,
    blocks: impl Iterator<Item = Block<'gcx>>,
    tainted: &mut HashSet<VariableId>,
)
Checks the bodies of mutually exclusive branches and keeps the taint of every branch that falls through, on top of the taint before the branch.